{
    "$graph": [
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/picard:b4d47c60366e12f8cc3ffb264e510c1165801eae1d6329d94ef9e6c30e972991"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 15000,
                    "ramMax": 15000,
                    "tmpdirMin": "$(Math.ceil(1.1 * inputs.INPUT.size / 1048576))",
                    "tmpdirMax": "$(Math.ceil(1.1 * inputs.INPUT.size / 1048576))",
                    "outdirMin": "$(Math.ceil(1.1 * inputs.INPUT.size / 1048576))",
                    "outdirMax": "$(Math.ceil(1.1 * inputs.INPUT.size / 1048576))"
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#picard_markduplicates.cwl/CREATE_INDEX",
                    "type": "string",
                    "default": "true",
                    "inputBinding": {
                        "prefix": "CREATE_INDEX=",
                        "separate": false
                    }
                },
                {
                    "id": "#picard_markduplicates.cwl/INPUT",
                    "type": "File",
                    "format": "#picard_markduplicates.cwl/format_2572",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false
                    }
                },
                {
                    "id": "#picard_markduplicates.cwl/TMP_DIR",
                    "default": ".",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "TMP_DIR=",
                        "separate": false
                    }
                },
                {
                    "id": "#picard_markduplicates.cwl/VALIDATION_STRINGENCY",
                    "default": "STRICT",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "VALIDATION_STRINGENCY=",
                        "separate": false
                    }
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.INPUT.basename)",
                    "prefix": "OUTPUT=",
                    "separate": false
                },
                {
                    "valueFrom": "$(inputs.INPUT.basename + \".metrics\")",
                    "prefix": "METRICS_FILE=",
                    "separate": false
                }
            ],
            "baseCommand": [
                "java",
                "-jar",
                "/usr/local/bin/picard.jar",
                "MarkDuplicates"
            ],
            "id": "#picard_markduplicates.cwl",
            "outputs": [
                {
                    "id": "#picard_markduplicates.cwl/OUTPUT",
                    "type": "File",
                    "format": "#picard_markduplicates.cwl/format_2572",
                    "outputBinding": {
                        "glob": "$(inputs.INPUT.basename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ]
                },
                {
                    "id": "#picard_markduplicates.cwl/METRICS",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.INPUT.basename + \".metrics\")"
                    }
                }
            ]
        },
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/picard_metrics_sqlite:501760b4e8a1edcb279ab735cd0476bb49779b26630391f5b582629d6c8bd90d"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 1000,
                    "ramMax": 1000,
                    "tmpdirMin": 1,
                    "tmpdirMax": 1,
                    "outdirMin": 1,
                    "outdirMax": 1
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/bam",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--bam"
                    }
                },
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/input_state",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--input_state"
                    }
                },
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/metric_path",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--metric_path"
                    }
                },
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/job_uuid",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--job_uuid"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid+\"_picard_MarkDuplicates.log\")"
                    }
                },
                {
                    "id": "#picard_markduplicates_to_sqlite.cwl/sqlite",
                    "format": "#picard_markduplicates_to_sqlite.cwl/format_3621",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + \".db\")"
                    }
                }
            ],
            "baseCommand": [
                "/usr/local/bin/picard_metrics_sqlite",
                "--metric_name",
                "MarkDuplicates"
            ],
            "id": "#picard_markduplicates_to_sqlite.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/bam",
                    "type": "File"
                },
                {
                    "id": "#main/job_uuid",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output",
                    "type": "File",
                    "outputSource": "#main/picard_markduplicates/OUTPUT"
                },
                {
                    "id": "#main/sqlite",
                    "type": "File",
                    "outputSource": "#main/picard_markduplicates_to_sqlite/sqlite"
                }
            ],
            "steps": [
                {
                    "id": "#main/picard_markduplicates",
                    "run": "#picard_markduplicates.cwl",
                    "in": [
                        {
                            "id": "#main/picard_markduplicates/INPUT",
                            "source": "#main/bam"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/picard_markduplicates/OUTPUT"
                        },
                        {
                            "id": "#main/picard_markduplicates/METRICS"
                        }
                    ]
                },
                {
                    "id": "#main/picard_markduplicates_to_sqlite",
                    "run": "#picard_markduplicates_to_sqlite.cwl",
                    "in": [
                        {
                            "id": "#main/picard_markduplicates_to_sqlite/bam",
                            "source": "#main/bam",
                            "valueFrom": "$(self.basename)"
                        },
                        {
                            "id": "#main/picard_markduplicates_to_sqlite/input_state",
                            "valueFrom": "markduplicates_readgroups"
                        },
                        {
                            "id": "#main/picard_markduplicates_to_sqlite/metric_path",
                            "source": "#main/picard_markduplicates/METRICS"
                        },
                        {
                            "id": "#main/picard_markduplicates_to_sqlite/job_uuid",
                            "source": "#main/job_uuid"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/picard_markduplicates_to_sqlite/sqlite"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
